'use server'
import prisma from "@/lib/db";
import { currentUser } from "@clerk/nextjs/server";
import { getOrganisation } from "./organisationActions";
//import { getUserNameWithId } from "./usersActions";


export async function createMember(id : string){
    try{
        const user = await currentUser()
        if(!user?.id){
            throw new Error("Error with user")
        }
        await prisma.membre.create({
            data :{
                userId : user?.id,
                organisationid : id,
                role: 'ADMIN'
            }
        })
        return {success : true}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function getMember(id : string){
    try{
        const user = await currentUser()
        if(!user?.id){
            throw new Error("Error with user")
        }

        const organisation = await getOrganisation(id)
        const result = await prisma.membre.findFirst(
        {
            where :{
                userId : user?.id,
                organisationid: organisation.Organisation?.id
            },
            select:{
                role:true
            }
        })
        return {success : true, role: result?.role }
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function getMembers(id: string){
    try{
        const user = await currentUser()
        const organisation = await getOrganisation(id)
        
        if(!user?.id){
            throw new Error("Error with user")
        }
        const result = await prisma.membre.findMany(
        {
            where :{
                userId : user?.id,
                organisationid: organisation.Organisation?.id
            }
        })

        const updatedResult = await Promise.all(result.map(async (user) => {
            const userName = await getUserNameWithId(user.userId); // Récupère le userName
            return { ...user, userName }; // Ajoute le userName à l'élément user
        }));
        
        return {success : true, listMembre: updatedResult }
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}