'use server'
import prisma from "@/lib/db";
import { currentUser } from "@clerk/nextjs/server";
//import { createMember } from "./memberActions";
import slugify from "slugify";
import {uploadImage,deleteImage} from '@/lib/uploadFile'

export async function updateOrganisation(
    nameOrganisation : string,
    idOrganisation : string,
    logoOrganisation : string, 
    typeOrganisation : string,
    tagOrganisation : string){
    try{
        const slugOrganisation = slugify(nameOrganisation)
        await prisma.organisation.upsert({
            where: { id: idOrganisation},
            update: {name : nameOrganisation, logo : logoOrganisation, type : typeOrganisation,tag : tagOrganisation, slug: slugOrganisation },
            create: {name : nameOrganisation, logo : logoOrganisation, type : typeOrganisation,tag : tagOrganisation, slug: slugOrganisation }
        })
        return {success : true}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

/*export async function createOrganisation(nameOrganisation : string,logoOrganisation : string, typeOrganisation : string,tagOrganisation: string){
    try{
        let slugOrganisation = ""
        if(slugOrganisation){
            let slugCandidate = slugify(nameOrganisation,{lower:true,strict:true})
            let slugExist = await getOrganisation(slugCandidate)
            let counter = 1
            while(slugExist){
                slugCandidate=`${slugCandidate}-${counter}`
                slugExist = await getOrganisation(slugCandidate)
                counter++
            }
            slugOrganisation = slugCandidate
        }
        const user = await currentUser()
        if(!user?.id){
            throw new Error("Error with user")
        }
        if(!logoOrganisation){
            logoOrganisation = '/assets/image0_0.jpg'
        }
        const result = await prisma.organisation.create({
            data : {
                name : nameOrganisation, 
                logo : logoOrganisation, 
                type : typeOrganisation,
                tag : tagOrganisation,
                slug : slugOrganisation
            }
        })

        await createMember(result.id)
        return {success : true}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function getOrganisations(){
    try{
        const user = await currentUser()
        if(!user){
            throw new Error ("Error with credential")
        }
        const listOrganisation = await prisma.membre.findMany(
            {where : {
                userId:user.id
            },
            select:{
                organisationid: true
            }})
        const listTemp: ({ id: string; name: string; tag: string; type: string; logo: string; } | null)[] = []
        const organisationPromise = listOrganisation.map(async organisation => {
            const temp = await prisma.organisation.findUnique({
                where : {
                    id: organisation.organisationid
                }
            })
           
           return temp
        }) 
        const result = await Promise.all(organisationPromise)
        listTemp.push(...result)
        return {success : true, listOrganisation : listTemp}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function deleteOrganisation(idOrganisation : string){
    try{
        await prisma.organisation.delete(
            {
                where: { 
                    id : idOrganisation
                },
            })
        return {success : true}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function getOrganisation(slugOrganisation : string ){
    try{
        const user = currentUser()
        if(!user){
            throw new Error("Error with credential")
        }

        const result = await prisma.organisation.findFirst({
            where :{
                slug:slugOrganisation
            }
        })

        if(!result){
            throw new Error ("Not found")
        }
        return {success : true, Organisation : result}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}


*/
export async function createOrganisation(formData : FormData){
    try{
        const {title,file,selectType,tag} = Object.fromEntries(formData)
        let slugOrganisation = ""
        let logo = ""
        if(!slugOrganisation){
            let slugCandidate = slugify(title.toString() ,{lower:true,strict:true})
            let slugExist = await prisma.organisation.findFirst({
                where : {
                    slug : slugCandidate
                    }
            })
            let counter = 1
            while(slugExist){
                slugCandidate=`${slugCandidate}-${counter}`
                slugExist = await prisma.organisation.findFirst({
                    where : {
                        slug : slugCandidate
                        }
                })
                counter++
            }
            slugOrganisation = slugCandidate
        }
        const resultUpdateImage = await uploadImage(file,slugOrganisation)
        const user = await currentUser()
        if(!user?.id){
            throw new Error("Error with user")
        }
        if(!resultUpdateImage.success){
            logo = '/assets/image0_0.jpg'
        }else{
            logo = resultUpdateImage.imageUrl
        }
        const result = await prisma.organisation.create({
            data : {
                name : title.toString(), 
                logo : logo, 
                type : selectType.toString(),
                tag : tag.toString(),
                slug : slugOrganisation
            }
        })
        return {success : true, result : result}
    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }

}

export async function getListOrganisations(userId : string){
    try{
        const result = await prisma.organisation.findMany({
            where :{
                members:{
                    some : {
                        userId
                    }
                },
                
            },
            select:{
                id : true,
                name: true,
                logo: true,
                slug: true
            }
        })
        if(!result){
            return{success : false, error : 'Error when retrieve all organisation', result : result}
        }
        return{success : true, result: result}

    }catch(error){
        return{success : false, error : error instanceof Error ? error.message : 'An unknown error occured'}
    }
}

export async function getOrganisation(slug : string){
    try {

        const user = await currentUser(); // 🔍 Récupère l'utilisateur connecté
        if (!user || !user.id) {
            return { success: false, error: "Utilisateur non authentifié" };
        }
        const organisation = await prisma.organisation.findFirst({
            where: { 
                slug:slug 
            },
            include: {
                members: {
                    include: {
                        user: { select: { id: true, userId: true,name: true } }, // Infos de l'utilisateur
                        role: { select: { id: true, name: true } } // Infos du rôle
                    }
                }
            }
        });
        const userCurrent = organisation?.members.find(member => member.user.userId === user?.id);

        if (!organisation) {
            return { success: false, error: "Organisation not found" };
        }

        return { 
            success: true, 
            organisation :{
                name : organisation.name,
                tag : organisation.tag,
                slug : organisation.slug,
                logo : organisation.logo,
                members : organisation.members
            }, 
            userCurrent: userCurrent ? { 
                role: userCurrent.role 
            } : null 
        };
    } catch (error) {
        return { success: false, error: error instanceof Error ? error.message : "An unknown error occurred" };
    }
}


export async function deleteOrganisation(slug : string){
    try{

        const verifOrga = await prisma.organisation.findFirst({
            where : {
                slug : slug
            }
        })
        if(verifOrga){
            const result = await prisma.organisation.delete({
                where :{
                    id: verifOrga.id
                }
            })
            if(result){

                if(!result.logo?.includes("image0_0")){
                    deleteImage(result.logo)
                }
                
                return { success: true };
            }
        }
        
        return { success: false, error: "pas d'orga trouvé" };
    }catch(error){
        return { success: false, error: error instanceof Error ? error.message : "An unknown error occurred" };
    }
}