'use client'
import React, { useState,useEffect } from 'react';
import 'leaflet/dist/leaflet.css';
//import L from 'leaflet'
import { LatLngTuple } from 'leaflet';
import '../../styles/map.css'
//import MapSearch from './MapSearch';
import { Button,Form } from 'react-bootstrap';
//import 'bootstrap/dist/css/bootstrap.min.css';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import {faPersonRifle,faCalendarDay,faFile,faEuroSign,faClock,faPeopleGroup} from '@fortawesome/free-solid-svg-icons'
//import ModalMapInfo from '../Informations/ModalMapInscription';
import dynamic from 'next/dynamic';
import L from 'leaflet'; // Import du type L

interface PositionInfo {
  name: string;
  position: LatLngTuple;
  customIcon: L.Icon<{ iconUrl: string; iconSize: [number, number]; iconAnchor: [number, number]; popupAnchor: [number, number]; }>;
  date: string;
  heure: string;
  paf: string;
  description: string;
  nbParticipant: string;
}

const MapWithNoSSR = dynamic(() => import('react-leaflet').then(mod => mod.MapContainer), {
  ssr: false,  // Empêche l'exécution côté serveur
});
const TileLayer = dynamic(() => import('react-leaflet').then(mod => mod.TileLayer), { ssr: false });
const Marker = dynamic(() => import('react-leaflet').then(mod => mod.Marker), { ssr: false });
const Popup = dynamic(() => import('react-leaflet').then(mod => mod.Popup), { ssr: false });
const ZoomControl = dynamic(() => import('react-leaflet').then(mod => mod.ZoomControl), { ssr: false });

export default function Home(){

  // Hook d'état pour listInfoPosition
  const [listInfoPosition,setListInfoPosition] = useState<PositionInfo[]>([]);  
  const position : LatLngTuple = [46.603354, 3.141249]
  const [LModule, setLModule] = useState<typeof L | null>(null); // pour stocker L côté client


  useEffect(() => {
    if (typeof window !== 'undefined') {
      import('leaflet').then(L => {
        setLModule(L); // Charge le module `L` côté client
      });
    }
  }, []); // Cela ne s'exécute qu'une seule fois au montage du composant côté client

  useEffect(() => {
    const positionTemp : PositionInfo[] = []
    if (LModule) {  
      const customIcon = new LModule.Icon({
          iconUrl: '/assets/logoEAN.png',  // Assurez-vous que le fichier est dans le dossier 'public/images/'
          iconSize: [40, 40],
          iconAnchor: [16, 32],
          popupAnchor: [0, -32],
        });
  
        const customIconTaff = new LModule.Icon({
          iconUrl: '/assets/logoTaff.png',  // Assurez-vous que le fichier est dans le dossier 'public/images/'
          iconSize: [32, 32],
          iconAnchor: [16, 32],
          popupAnchor: [0, -32],
        });
        
        let positionTempInfo : PositionInfo = 
          { 
              name : "Equipe Airsoft Nord",
              position : [50.78794581996757, 2.402059344182279],
              customIcon : customIcon,
              date: "05/01/2025",
              heure : "8h30-16h",
              paf : "8€",
              description : " Ce dimanche 05 janvier, les EAN organisent leur premiere partie de l'année sur leur terrain.",
              nbParticipant : "0/20"
          }
        positionTemp.push(positionTempInfo)
        positionTempInfo =
          {
              name : "Taff",
              position : [50.35071567603138, 3.309760157697385],
              customIcon : customIconTaff,
              date: "05/01/2025",
              heure : "8h30-16h",
              paf : "10€",
              description : "salut c&apos;est la taff",
              nbParticipant : "0/40"
          }
      positionTemp.push(positionTempInfo)
      setListInfoPosition(positionTemp)
    }
  }, [LModule]);

  useEffect(() => {

  },[])
    return(
       <div style={{ height: "94vh" }}>
        {/*<MapSearch />*/}
        <MapWithNoSSR center={position} zoom={7} style={{ height: "100%", width: "100%",zIndex:0 }} minZoom={7} zoomControl={false}>
          {/* Chargement des tuiles OpenStreetMap */}
          <ZoomControl position="topright" />
          <TileLayer
            attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
            url="https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
          />
          
          {/* Ajout d'un marker */}
          {listInfoPosition.map((data,index) =>
          <Marker key={index} position={data.position} icon={data.customIcon}>
            <Popup >
              <div className="container">
                 <Form>
                    <Form.Group>
                        <Form.Label><FontAwesomeIcon icon={faPersonRifle} /> : <strong>{data.name}</strong></Form.Label>
                     </Form.Group>
                     <Form.Group>
                         <Form.Label><FontAwesomeIcon icon={faCalendarDay} /> : {data.date}   <FontAwesomeIcon icon={faClock} /> : {data.heure}</Form.Label>
                     </Form.Group>
                     <Form.Group>
                        <Form.Label><FontAwesomeIcon icon={faFile} /> : {data.description}</Form.Label>
                     </Form.Group>
                     <Form.Group>
                        <Form.Label><FontAwesomeIcon icon={faEuroSign} /> : {data.paf}</Form.Label>
                     </Form.Group>
                     <Form.Group>
                        <Form.Label><FontAwesomeIcon icon={faPeopleGroup} /> : {data.nbParticipant}</Form.Label>
                     </Form.Group>
                     <Form.Group className="d-grid gap-2">
                        <Button  size='sm' variant='dark' >S&apos;inscrire</Button>
                     </Form.Group>
                  </Form>
              </div>
            </Popup>
          </Marker>
        )}
        </MapWithNoSSR>
        {/*<ModalMapInfo isOpen={isModalOpen} onClose={closeModal}/>*/}
      </div>
    )
}