
"use client"

import {useEffect, useRef, useState} from 'react'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import {faTrash,faPenToSquare,faCamera,faCheck, faCancel} from '@fortawesome/free-solid-svg-icons'
import Image from 'next/image'
import logoDefault from 'p/assets/image0_0.jpg'
import {getOrganisationMethods,deleteOrganisationMethods } from "@/methods/organisationMethods"
import { useRouter } from 'next/navigation'
import ConfirmDeleteModal from '@/components/ConfirmeDeleteModal'


export default function pageOrganisation({params}) {
  const router = useRouter()
  const [infoOrganisation,setInfoOrganisation] = useState("")
  const [listMember,setListMember] = useState([])
  const [error,setError] = useState("")
  const [role,setRole] = useState("")
  const [isEnable,setIsEnable] = useState(false)
  const refImageChange = useRef(null)
  const [image, setImage] = useState(null);
  const [isModalOpen, setModalOpen] = useState(false);
  const [hiddenError,setHiddenError] = useState(true)


  async function getSlug(){
    const {slugOrganisation } = await params
    return slugOrganisation
  }

  

  useEffect(() => {
        fetchOrganisation()
   },[])

   function handleEnableModify(e){
      e.preventDefault()
      setIsEnable(true)
   }

   function handleEnableChangeImage(e){
      e.preventDefault()
        refImageChange.current.click()
   }
    // Fonction qui gère la sélection d'une nouvelle image
    const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      // Crée un URL temporaire pour l'image sélectionnée
      const imageUrl = URL.createObjectURL(file);
      setImage(imageUrl);
    }
  };

  async function fetchOrganisation() {
    try{
        const result = await getOrganisationMethods(await getSlug())
        console.log(result)
        if(result.success){
            setInfoOrganisation(result.result.organisation)
            setListMember(result.result.organisation.members)
            setImage(result.result.organisation.logo)      
            setRole(result.result.userCurrent.role.name)
        }

    }catch(e){
        setError("une erreur s'est produite : " + e)
    }
  }
   async function handleDisableModify(e){
    e.preventDefault()
        try{
          fetchOrganisation()
      }catch(e){
          setError("une erreur s'est produite : " + e)
      }
      setIsEnable(false)
   }

   async function handleDeleteOrga(e){
    e.preventDefault()
      setHiddenError(true)
      try{  
          const result = await deleteOrganisationMethods(await getSlug())
          if(result){
             router.push('/organisations')
          }   
          setModalOpen(false);
          setError('Erreur lors de la suppression essayer plus tard')
          setHiddenError(false)

      }catch(err){
        setError("une erreur s'est produite : " + e)
      }
   }
   
  return (
    <main className='u-main-container'>
      <div hidden={hiddenError}
          className='text-center text-sm bg-red-100 border border-red-600 rounded'> 
        <p className='text-red-600'>{error}</p>
      </div>

        <div className='shadow-md bg-zinc-700 rounded-t flex justify-between items-center p-2 mb-3 relative' >
          <div className='relative w-1/5'>
          <Image 
          src={image ? image : logoDefault}  
          alt="logo Organisation" 
          width={500} 
          height={500}
          className='w-full mr-3 object-contain rounded-xl cursor-pointer border border-gray-500'
          onClick={handleEnableChangeImage}/>  

            <FontAwesomeIcon 
              icon={faCamera} 
              className="absolute bottom-0 right-0 bg-gray-700 text-white p-1 rounded-full w-5 h-5 cursor-pointer"
              onClick={handleEnableChangeImage} 
            />

          <input
            ref={refImageChange}
            type="file"
            id="image-input"
            style={{ display: 'none' }}
            accept="image/*"
          />
      
        </div>
        {role === "ADMIN" && 
          <div className='absolute top-0 right-0 flex space-x-2 p-2 mt-2'>
            <button 
              type='button'
              className={`${isEnable ? 'hidden' : 'block' } border border-gray-500 rounded-xl px-3 py-1 bg-gray-200 text-xs flex items-center space-x-1`}
              onClick={handleEnableModify}
              hidden={isEnable}><FontAwesomeIcon icon={faPenToSquare }/> &nbsp;Modify</button>
            <button 
              type='button' 
              //onClick={handleDeleteOrga}
              onClick={() => setModalOpen(true)}
              className={`${isEnable ? 'block' : 'hidden' } border border-red-500 rounded-xl px-3 py-1 bg-red-500 text- text-white text-xs flex items-center space-x-1`}
             ><FontAwesomeIcon icon={faTrash }/>&nbsp; Delete</button>
          </div>
      }
      </div>
      <form >
        <fieldset className='border rounded border-gray-400 mb-4 shadow-md'>
          <legend className='text-sm font-semibold px-2'>Détail </legend>
          <div className='flex flex-row pt-4'>
                <label className='f-label w-1/2 pt-3 pr-3'>Name</label>
              <input 
                type="text"
                disabled={!isEnable} 
                className="f-input" 
                value={infoOrganisation.name || ''} 
                onChange={e => setInfoOrganisation({...infoOrganisation, name: e.target.value})}></input>
            </div>

            <div className='flex flex-row'>
              <label className='f-label w-1/2 pt-3 pr-3'>Tag :</label>
              <input 
                type="text"
                disabled={!isEnable} 
                className="f-input" 
                value={infoOrganisation.tag || ''} 
                onChange={e => setInfoOrganisation({...infoOrganisation, tag: e.target.value})}></input>
            </div>
            <div className='flex flex-row'>
              <label className='f-label w-1/2 pt-3 pr-3'>Team :</label>
              <input 
                type="text" 
                disabled={!isEnable}
                className="f-input"  
                value={infoOrganisation.team || ''} 
                onChange={e => setInfoOrganisation({...infoOrganisation, team: e.target.value})}></input>
            </div>
            <div  className='flex flex-row justify-end space-x-2 mr-4 mb-2'>
                <button 
                  type="button" 
                  hidden={!isEnable} 
                  className='m-1 px-2 py-1 bg-green-700 text-white text-xs font-semibold rounded  text-center'><FontAwesomeIcon icon={faCheck }/>&nbsp;Validate</button>
                <button 
                  type="button" 
                  hidden={!isEnable} 
                  className='m-1 px-2 py-1  bg-red-700 text-white text-xs font-semibold rounded text-center'
                  onClick={handleDisableModify}><FontAwesomeIcon icon={faCancel }/>&nbsp; Cancel</button>
            </div>
      </fieldset>
      </form>
      <fieldset className='border rounded border-gray-400 mb-4 py-2 shadow-md'>
      <legend className='text-sm font-semibold px-2 '>Membres et role </legend>
            {
              Array.isArray(listMember) && listMember.length > 0 ? (
                listMember.map((member) => (
                  <div className='flex flex-row' key={member.user.id}>
                    <p className='text-sm w-1/3 text-center' scope="row" >{member.user.name} </p>
                    <p className='text-sm  text-center' scope="row" >|</p>
                    <p className='text-sm w-1/3 text-center' scope="row" >{member.role.name}</p>
                    <p className='text-sm  text-center' scope="row" >|</p>
                    <div className='flex flex-row space-x-2'>
                        <button type="button" className='items-center flex'>test</button>
                    </div>
                  </div>
                ))
              ) : (
                 <p  className='w-full text-center' >Aucun membre trouvé</p>
              )
            } 
      </fieldset>
      <ConfirmDeleteModal
        isOpen={isModalOpen}
        onClose={() => setModalOpen(false)}
        onConfirm={handleDeleteOrga}
      />
    </main>
  )
}
