
'use client'
import React, { useEffect, useState } from "react";
import Image from "next/image";
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import {faSearch,faPlus} from '@fortawesome/free-solid-svg-icons'
import { useRouter } from "next/navigation";
import Link from "next/link";
import { getListOrganisationsMethod } from "@/methods/organisationMethods";

export default function OrganisationsPage(){
    const [listOrganisation,setListOrganisation] = useState([])
    const router = useRouter()
    const [loading, setLoading] = useState(false);

    function handleCreateOrganisation(e){
        router.push('/organisations/create')
    }
    function handleSearchOrganisation(e){
        router.push('/organisations/search')
    }

    useEffect(() => {
        const fetchOrganisation = async() => {
            try{
                const result = await getListOrganisationsMethod()
                if(result.success){
                    const listTemp = result.result?.result
                    setListOrganisation(listTemp)
                }
            }catch(e){
                setError("une erreur s'est produite : " + e)
            }
        }
        fetchOrganisation()
        setLoading(false)
    },[])

    
    if (loading) {
        return (
          <div className="flex items-center justify-center min-h-screen">
            <div className="animate-spin rounded-full h-16 w-16 border-t-4 border-blue-500 border-solid"></div>
          </div>
        );
    }
    return (
        <main className="u-main-container bg-white">
            <div>
                 <div className="bg-gray-500 border-solid border text-white shadow-lg rounded flex justify-between items-center p-2">
                  <p className="mx-2">Vos organisations :</p>
                 <div className="flex space-x-2">
                   <button 
                        type="button" 
                        onClick={handleCreateOrganisation} 
                        className="shadow text-xs text-black bg-gray-100 border border-gray-500 rounded-full px-3 py-1 hover:bg-gray-300"
                        >
                        <FontAwesomeIcon icon={faPlus} /> Add
                    </button>
                    <button 
                        type="button" 
                        onClick={handleSearchOrganisation} 
                        className="shadow text-xs text-black bg-green-100 border border-green-500 rounded-full px-3 py-1 hover:bg-green-300"
                    >
                        <FontAwesomeIcon icon={faSearch} /> Search
                    </button>
                </div>
                </div>

                            {listOrganisation.map((organisation) => (
                                <Link key={organisation.id} href={`/organisations/${organisation.slug}`}>
                                <li  className="bg-white rounded-sm list-none type shadow-md hover:shadow-xl border hover:border-zinc-300">
                                    <div >
                                        <div className="flex  p-1 grow " > 
                                            <Image src={organisation.logo} width={100} height={50} alt="logo"></Image>
                                            <div className="ml-2 mr-5 w-full flex flex-col justify-center text-center overflow-hidden">
                                                <p className="text-gray-700 text-sm hover:text-gray-600 p-1">{organisation.name}</p>
                                            </div>
                                        </div>
                                    </div>
                                </li>
                                </Link>
                            ))}
                
            </div>
      </main>  
    )
}