"use client";

import { useEffect } from "react";

interface ConfirmDeleteModalProps {
  isOpen: boolean;
  onClose: () => void;
  onConfirm: () => void;
}

export default function ConfirmDeleteModal({ isOpen, onClose, onConfirm }: ConfirmDeleteModalProps) {
  // Empêche le défilement quand la modale est ouverte
  useEffect(() => {
    if (isOpen) document.body.style.overflow = "hidden";
    else document.body.style.overflow = "auto";
  }, [isOpen]);

  if (!isOpen) return null;

  return (
    <div className="fixed inset-0 flex items-center justify-center bg-black bg-opacity-50 z-50">
      {/* Contenu de la modale */}
      <div className="bg-white p-6 rounded-xl shadow-lg max-w-sm w-full border border-gray-500">
        <h2 className="text-lg font-semibold text-gray-800">Confirmer la suppression</h2>
        <p className="text-gray-600 mt-2">Êtes-vous sûr de vouloir supprimer cette donnée ? Cette action est irréversible.</p>
        
        {/* Boutons */}
        <div className="flex justify-end mt-4 space-x-2">
          <button 
            onClick={onClose} 
            className="px-4 py-2 text-gray-700 bg-gray-200 rounded-lg hover:bg-gray-300 transition"
          >
            Annuler
          </button>
          <button 
            onClick={onConfirm} 
            className="px-4 py-2 text-white bg-red-600 rounded-lg hover:bg-red-700 transition"
          >
            Supprimer
          </button>
        </div>
      </div>
    </div>
  );
}
