'use client'

import { Disclosure, DisclosureButton, DisclosurePanel, Menu, MenuButton, MenuItem, MenuItems} from '@headlessui/react'
import { Bars3Icon, BellIcon, XMarkIcon } from '@heroicons/react/24/outline'
import Link from 'next/link'

import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import {faUser,faSignIn,faSignOut} from '@fortawesome/free-solid-svg-icons'
import { useRouter } from 'next/navigation'
import Image from 'next/image'
import logoAs from "../../public/assets/logoAS.png"

import {
  SignedIn,
  SignedOut,
  UserButton,
} from '@clerk/nextjs'

import { useEffect } from 'react'
import {createUser,getUser} from "@/actions/usersActions" 




const  NavbarsMenu = () => {

  /*useEffect(() =>{
    const  verifUser = async () =>{
      try{  
        let resultVerif = await getUser()       
        if(!resultVerif.success){
          const verifCreateUser = await createUser()
          if(!verifCreateUser.success){
            throw new Error("Error with create credential")
          }
        }
      }catch(err){
        throw new Error("Error with credential")
      }
    }
    verifUser()
  },[])*/


  const router = useRouter()

  const handleRedirectConnexion = () => {
    router.push('/sign-in'); // Redirige vers la page "/sign-in"
  };

  const handleRedirectInscription = () => {
    router.push('/sign-in'); // Redirige vers la page "/sign-in"
  };

  const navigation = [
    { name: 'Organisations', href: '/organisations', current: false }
  ]

  function classNames(...classes) {
    return classes.filter(Boolean).join(' ')
  }
    return (
      <Disclosure as="nav" className="bg-gray-800">
      <div className="mx-auto max-w-7xl px-2 sm:px-6 lg:px-8">
        <div className="relative flex h-16 items-center justify-between">
          <div className="absolute inset-y-0 left-0 flex items-center sm:hidden">
            {/* Mobile menu button*/}
            <DisclosureButton className="group relative inline-flex items-center justify-center rounded-md p-2 text-gray-400 hover:bg-gray-700 hover:text-white focus:ring-2 focus:ring-white focus:outline-hidden focus:ring-inset">
              <span className="absolute -inset-0.5" />
              <span className="sr-only">Open main menu</span>
              <Bars3Icon aria-hidden="true" className="block size-6 group-data-open:hidden" />
              <XMarkIcon aria-hidden="true" className="hidden size-6 group-data-open:block" />
            </DisclosureButton>
          </div>
          <div className="flex flex-1 items-center justify-center sm:items-stretch sm:justify-start">
            <div className="flex shrink-0 items-center">
              <Link href='/'><Image
                alt="Airsoft Search"
                src={logoAs}
                className="h-8 w-auto"
                width={50}
                height={50}
              /></Link>
            </div>
            <div className="hidden sm:ml-6 sm:block">
              <div className="flex space-x-4">
                {navigation.map((item) => (
                  <a
                    key={item.name}
                    href={item.href}
                    aria-current={item.current ? 'page' : undefined}
                    className={classNames(
                      item.current ? 'bg-gray-900 text-white' : 'text-gray-300 hover:bg-gray-700 hover:text-white',
                      'rounded-md px-3 py-2 text-sm font-medium',
                    )}
                  >
                    {item.name}
                  </a>
                ))}
              </div>
            </div>
          </div>
          <div className="absolute inset-y-0 right-0 flex items-center pr-2 sm:static sm:inset-auto sm:ml-6 sm:pr-0">
            <button
              type="button"
              className="relative rounded-full bg-gray-800 p-1 text-gray-400 hover:text-white focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-gray-800 focus:outline-hidden"
            >
              <span className="absolute -inset-1.5" />
              <span className="sr-only">View notifications</span>
              <BellIcon aria-hidden="true" className="size-6" />
            </button>

            {/* Profile dropdown */}
             <Menu as="div" className="relative ml-3">
             <div>
             <SignedOut>
                <MenuButton className="relative flex rounded-full bg-gray-800 text-sm focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-gray-800 focus:outline-hidden">
                  <span className="absolute -inset-1.5" />
                  <span className="sr-only">Open user menu</span>
                  <FontAwesomeIcon icon={faUser} />
                </MenuButton>
                </SignedOut>
              </div>
              

              <MenuItems
                transition
                className="absolute right-0 z-10 mt-2 w-40 origin-top-right rounded-md bg-white py-1 ring-1 shadow-lg ring-black/5 transition focus:outline-hidden data-closed:scale-95 data-closed:transform data-closed:opacity-0 data-enter:duration-100 data-enter:ease-out data-leave:duration-75 data-leave:ease-in"
              >
                <MenuItem>
                  <div
                    className="block px-4 py-2 text-sm text-gray-700 data-focus:bg-gray-100 data-focus:outline-hidden"
                  >
                      <button onClick={handleRedirectConnexion} >
                      <FontAwesomeIcon icon={faSignIn} /> Connexion 
                      </button>
                    </div>
                </MenuItem>
                <MenuItem>
                  <div
                    className="block px-4 py-2 text-sm text-gray-700 data-focus:bg-gray-100 data-focus:outline-hidden"
                  >
                    <button onClick={handleRedirectInscription}>
                      <FontAwesomeIcon icon={faSignOut} /> Inscription 
                    </button>
                  </div>
                </MenuItem>
                </MenuItems>
               
                <SignedIn>
                  <UserButton />
                </SignedIn>
            </Menu>
          </div>
        </div>
      </div>

      <DisclosurePanel className="sm:hidden">
        <div className="space-y-1 px-2 pt-2 pb-3">
          {navigation.map((item) => (
            <DisclosureButton
              key={item.name}
              as="a"
              href={item.href}
              aria-current={item.current ? 'page' : undefined}
              className={classNames(
                item.current ? 'bg-gray-900 text-white' : 'text-gray-300 hover:bg-gray-700 hover:text-white',
                'block rounded-md px-3 py-2 text-base font-medium',
              )}
            >
              {item.name}
            </DisclosureButton>
          ))}
        </div>
      </DisclosurePanel>
  </Disclosure>  
      
    );
  };
  
  export default NavbarsMenu;