"use server";

import fs from "fs";
import path from "path";

export async function uploadImage(file,slug) {
  "use server";


  // Vérifier le type de fichier (optionnel)
  const allowedTypes = ["image/png", "image/jpeg", "image/jpg", "image/webp"];
  if (!allowedTypes.includes(file.type)) {
    return { error: "Format non supporté (PNG, JPG, WEBP seulement)" };
  }

  // Lire le fichier en tant que buffer
  const bytes = await file.arrayBuffer();
  const buffer = Buffer.from(bytes);

  // Définir le dossier d'upload
  const uploadDir = path.join(process.cwd(), "public/assets/avatar/avatarOrganisations");
  if (!fs.existsSync(uploadDir)) {
    fs.mkdirSync(uploadDir, { recursive: true });
  }

  // Générer un nouveau nom unique
  const fileExt = path.extname(file.name); // Obtenir l'extension (.jpg, .png, etc.)
  const newFileName = `${slug}${fileExt}`; // Exemple: image_123e4567-e89b-12d3-a456-426614174000.png
  const filePath = path.join(uploadDir, newFileName);

  // Écrire le fichier avec le nouveau nom
  fs.writeFileSync(filePath, buffer);

  // URL accessible de l'image
  const imageUrl = `/assets/avatar/avatarOrganisations/${newFileName}`;

  // Revalider le cache pour rafraîchir l'affichage
  return { success: true, imageUrl };
}

export async function deleteImage(imagePath) {
  if (!imagePath) {
    return { error: "Chemin de l'image non fourni" };
  }

  // Assurer que le fichier est bien dans /public/assets
  const fullPath = path.join(process.cwd(), "public", imagePath);

  if (!fs.existsSync(fullPath)) {
    return { error: "Fichier introuvable" };
  }

  try {
    fs.unlinkSync(fullPath); // Supprime l'image
    return { success: true, message: "Image supprimée avec succès" };
  } catch (error) {
    return { error: "Erreur lors de la suppression de l'image" , message : error.message };
  }
}

